#!/bin/sh
echo 'name: conduit
version: 1.0.5
id: conduit-1.0.5-ce3f9f004c36788494ca8505e33f8cdd

license: BSD3
copyright:
maintainer: michael@snoyman.com
stability:
homepage: http://github.com/snoyberg/conduit
package-url:
synopsis: Streaming data processing library.
description: @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://haskell.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
             .
             Release history:
             .
             [1.0] Simplified the user-facing interface back to the Source, Sink, and Conduit types, with Producer and Consumer for generic code. Error messages have been simplified, and optional leftovers and upstream terminators have been removed from the external API. Some long-deprecated functions were finally removed.
             .
             [0.5] The internals of the package are now separated to the .Internal module, leaving only the higher-level interface in the advertised API. Internally, switched to a @Leftover@ constructor and slightly tweaked the finalization semantics.
             .
             [0.4] Inspired by the design of the pipes package: we now have a single unified type underlying @Source@, @Sink@, and @Conduit@. This type is named @Pipe@. There are type synonyms provided for the other three types. Additionally, @BufferedSource@ is no longer provided. Instead, the connect-and-resume operator, @$$+@, can be used for the same purpose.
             .
             [0.3] ResourceT has been greatly simplified, specialized for IO, and moved into a separate package. Instead of hard-coding ResourceT into the conduit datatypes, they can now live around any monad. The Conduit datatype has been enhanced to better allow generation of streaming output. The SourceResult, SinkResult, and ConduitResult datatypes have been removed entirely.
             .
             [0.2] Instead of storing state in mutable variables, we now use CPS. A @Source@ returns the next @Source@, and likewise for @Sink@s and @Conduit@s. Not only does this take better advantage of GHC\'\''s optimizations (about a 20% speedup), but it allows some operations to have a reduction in algorithmic complexity from exponential to linear. This also allowed us to remove the @Prepared@ set of types. Also, the @State@ functions (e.g., @sinkState@) use better constructors for return types, avoiding the need for a dummy state on completion.
             .
             [0.1] @BufferedSource@ is now an abstract type, and has a much more efficient internal representation. The result was a 41% speedup on microbenchmarks (note: do not expect speedups anywhere near that in real usage). In general, we are moving towards @BufferedSource@ being a specific tool used internally as needed, but using @Source@ for all external APIs.
             .
             [0.0] Initial release.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules: Data.Conduit Data.Conduit.Binary Data.Conduit.Text
                 Data.Conduit.List Data.Conduit.Lazy Data.Conduit.Internal
                 Data.Conduit.Util
hidden-modules: System.PosixFile
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/conduit-1.0.5
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/conduit-1.0.5
              /usr/local/lib
hs-libraries: HSconduit-1.0.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         bytestring-0.10.0.2-59abd9894532f476aabac207680aae43
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         directory-1.2.0.1-9eaa01c28e06d5c85f67c966a03a9e57
         lifted-base-0.2.0.5-d32c32bc1fa1f68137cfd9d588255252
         mmorph-1.0.0-20a6abb10acd5d213e6c72450f873a5d
         monad-control-0.3.2.1-690b4ca3d786c1114046ba4e239e464f
         resourcet-0.4.7.1-88892ed88664d06cd6c55486908855cd
         text-0.11.3.1-b49365bcfaf3954e4484c36c86c98126
         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
         transformers-base-0.4.1-da9c4a03c3accfcef7f09e5e6d753fad
         void-0.6-085941cdab66cf1cbc46df01b2f33577
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/conduit-1.0.5/html/conduit.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/conduit-1.0.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
